@@ -51,7 +51,7 @@ class ClientManager(clientmanager.ClientManager):
         api_version=None,
         pw_func=None,
     ):
-        super(ClientManager, self).__init__(
+        super().__init__(
             cli_options=cli_options,
             api_version=api_version,
             pw_func=pw_func,
@@ -94,7 +94,7 @@ class ClientManager(clientmanager.ClientManager):
             except TypeError as e:
                 self._fallback_load_auth_plugin(e)
 
-        return super(ClientManager, self).setup_auth()
+        return super().setup_auth()
 
     def _fallback_load_auth_plugin(self, e):
         # NOTES(RuiChen): Hack to avoid auth plugins choking on data they don't
@@ -133,7 +133,17 @@ class ClientManager(clientmanager.ClientManager):
         # NOTE(jcross): Cinder did some interesting things with their service
         #               name so we need to figure out which version to look
         #               for when calling is_service_available()
-        volume_version = volume_client.api_version.ver_major
+        endpoint_data = volume_client.get_endpoint_data()
+        # Not sure how endpoint data stores the api version for v2 API,
+        # for v3 it is a tuple (3, 0)
+        if endpoint_data.api_version and isinstance(
+            endpoint_data.api_version, tuple
+        ):
+            volume_version = endpoint_data.api_version[0]
+        else:
+            # Setting volume_version as 2 here if it doesn't satisfy the
+            # conditions for version 3
+            volume_version = 2
         if (
             self.is_service_available("volumev%s" % volume_version)
             is not False
@@ -170,7 +180,9 @@ def get_plugin_modules(group):
             module = importlib.import_module(module_name)
         except Exception as err:
             sys.stderr.write(
-                "WARNING: Failed to import plugin %s: %s.\n" % (ep.name, err)
+                "WARNING: Failed to import plugin {}: {}.\n".format(
+                    ep.name, err
+                )
             )
             continue
 
