@@ -17,7 +17,6 @@ from unittest import mock
 from unittest.mock import call
 
 from openstack import exceptions as sdk_exceptions
-from openstack import utils as sdk_utils
 from osc_lib.cli import format_columns
 from osc_lib import exceptions
 
@@ -58,7 +57,7 @@ class TestAggregate(compute_fakes.TestComputev2):
 
 class TestAggregateAddHost(TestAggregate):
     def setUp(self):
-        super(TestAggregateAddHost, self).setUp()
+        super().setUp()
 
         self.compute_sdk_client.find_aggregate.return_value = self.fake_ag
         self.compute_sdk_client.add_host_to_aggregate.return_value = (
@@ -89,7 +88,7 @@ class TestAggregateAddHost(TestAggregate):
 
 class TestAggregateCreate(TestAggregate):
     def setUp(self):
-        super(TestAggregateCreate, self).setUp()
+        super().setUp()
 
         self.compute_sdk_client.create_aggregate.return_value = self.fake_ag
         self.compute_sdk_client.set_aggregate_metadata.return_value = (
@@ -159,7 +158,7 @@ class TestAggregateDelete(TestAggregate):
     fake_ags = compute_fakes.create_aggregates(count=2)
 
     def setUp(self):
-        super(TestAggregateDelete, self).setUp()
+        super().setUp()
 
         self.compute_sdk_client.find_aggregate = compute_fakes.get_aggregates(
             self.fake_ags
@@ -267,7 +266,7 @@ class TestAggregateList(TestAggregate):
     )
 
     def setUp(self):
-        super(TestAggregateList, self).setUp()
+        super().setUp()
 
         self.compute_sdk_client.aggregates.return_value = [self.fake_ag]
         self.cmd = aggregate.ListAggregate(self.app, None)
@@ -295,7 +294,7 @@ class TestAggregateList(TestAggregate):
 
 class TestAggregateRemoveHost(TestAggregate):
     def setUp(self):
-        super(TestAggregateRemoveHost, self).setUp()
+        super().setUp()
 
         self.compute_sdk_client.find_aggregate.return_value = self.fake_ag
         self.compute_sdk_client.remove_host_from_aggregate.return_value = (
@@ -326,7 +325,7 @@ class TestAggregateRemoveHost(TestAggregate):
 
 class TestAggregateSet(TestAggregate):
     def setUp(self):
-        super(TestAggregateSet, self).setUp()
+        super().setUp()
 
         self.compute_sdk_client.find_aggregate.return_value = self.fake_ag
         self.cmd = aggregate.SetAggregate(self.app, None)
@@ -513,7 +512,7 @@ class TestAggregateShow(TestAggregate):
     )
 
     def setUp(self):
-        super(TestAggregateShow, self).setUp()
+        super().setUp()
 
         self.compute_sdk_client.find_aggregate.return_value = self.fake_ag
         self.cmd = aggregate.ShowAggregate(self.app, None)
@@ -537,7 +536,7 @@ class TestAggregateShow(TestAggregate):
 
 class TestAggregateUnset(TestAggregate):
     def setUp(self):
-        super(TestAggregateUnset, self).setUp()
+        super().setUp()
 
         self.compute_sdk_client.find_aggregate.return_value = self.fake_ag
         self.cmd = aggregate.UnsetAggregate(self.app, None)
@@ -598,7 +597,7 @@ class TestAggregateCacheImage(TestAggregate):
     images = image_fakes.create_images(count=2)
 
     def setUp(self):
-        super(TestAggregateCacheImage, self).setUp()
+        super().setUp()
 
         self.compute_sdk_client.find_aggregate.return_value = self.fake_ag
         self.find_image_mock = mock.Mock(side_effect=self.images)
@@ -608,8 +607,9 @@ class TestAggregateCacheImage(TestAggregate):
 
         self.cmd = aggregate.CacheImageForAggregate(self.app, None)
 
-    @mock.patch.object(sdk_utils, 'supports_microversion', return_value=False)
-    def test_aggregate_not_supported(self, sm_mock):
+    def test_aggregate_cache_pre_v281(self):
+        self.set_compute_api_version('2.80')
+
         arglist = ['ag1', 'im1']
         verifylist = [
             ('aggregate', 'ag1'),
@@ -620,8 +620,9 @@ class TestAggregateCacheImage(TestAggregate):
             exceptions.CommandError, self.cmd.take_action, parsed_args
         )
 
-    @mock.patch.object(sdk_utils, 'supports_microversion', return_value=True)
-    def test_aggregate_add_single_image(self, sm_mock):
+    def test_aggregate_cache_add_single_image(self):
+        self.set_compute_api_version('2.81')
+
         arglist = ['ag1', 'im1']
         verifylist = [
             ('aggregate', 'ag1'),
@@ -636,8 +637,9 @@ class TestAggregateCacheImage(TestAggregate):
             self.fake_ag.id, [self.images[0].id]
         )
 
-    @mock.patch.object(sdk_utils, 'supports_microversion', return_value=True)
-    def test_aggregate_add_multiple_images(self, sm_mock):
+    def test_aggregate_cache_add_multiple_images(self):
+        self.set_compute_api_version('2.81')
+
         arglist = [
             'ag1',
             'im1',
