@@ -47,7 +47,7 @@ TEST_RESPONSE_DICT_V3.set_project_scope()
 TEST_VERSIONS = fixture.DiscoveryList(href=AUTH_URL)
 
 
-class FakeStdout(object):
+class FakeStdout:
     def __init__(self):
         self.content = []
 
@@ -61,7 +61,7 @@ class FakeStdout(object):
         return result
 
 
-class FakeLog(object):
+class FakeLog:
     def __init__(self):
         self.messages = {}
 
@@ -81,7 +81,7 @@ class FakeLog(object):
         self.messages['critical'] = msg
 
 
-class FakeApp(object):
+class FakeApp:
     def __init__(self, _stdout, _log):
         self.stdout = _stdout
         self.client_manager = None
@@ -92,18 +92,18 @@ class FakeApp(object):
         self.log = _log
 
 
-class FakeOptions(object):
+class FakeOptions:
     def __init__(self, **kwargs):
         self.os_beta_command = False
 
 
-class FakeClient(object):
+class FakeClient:
     def __init__(self, **kwargs):
         self.endpoint = kwargs['endpoint']
         self.token = kwargs['token']
 
 
-class FakeClientManager(object):
+class FakeClientManager:
     _api_version = {
         'image': '2',
     }
@@ -158,7 +158,7 @@ class FakeClientManager(object):
         return self.volume_endpoint_enabled
 
 
-class FakeModule(object):
+class FakeModule:
     def __init__(self, name, version):
         self.name = name
         self.__version__ = version
@@ -167,7 +167,7 @@ class FakeModule(object):
         self.version.__version__ = version
 
 
-class FakeResource(object):
+class FakeResource:
     def __init__(self, manager=None, info=None, loaded=False, methods=None):
         """Set attributes and methods for a resource.
 
@@ -210,8 +210,8 @@ class FakeResource(object):
         reprkeys = sorted(
             k for k in self.__dict__.keys() if k[0] != '_' and k != 'manager'
         )
-        info = ", ".join("%s=%s" % (k, getattr(self, k)) for k in reprkeys)
-        return "<%s %s>" % (self.__class__.__name__, info)
+        info = ", ".join(f"{k}={getattr(self, k)}" for k in reprkeys)
+        return f"<{self.__class__.__name__} {info}>"
 
     def keys(self):
         return self._info.keys()
@@ -237,7 +237,7 @@ class FakeResponse(requests.Response):
     def __init__(
         self, headers=None, status_code=200, data=None, encoding=None
     ):
-        super(FakeResponse, self).__init__()
+        super().__init__()
 
         headers = headers or {}
 
