@@ -13,43 +13,37 @@
 #   under the License.
 #
 
-from keystoneclient import exceptions as identity_exc
+from openstack import exceptions as sdk_exceptions
+from openstack.identity.v3 import service as _service
+from openstack.test import fakes as sdk_fakes
 from osc_lib import exceptions
 
 from openstackclient.identity.v3 import service
 from openstackclient.tests.unit.identity.v3 import fakes as identity_fakes
 
 
-class TestService(identity_fakes.TestIdentityv3):
-    def setUp(self):
-        super(TestService, self).setUp()
-
-        # Get a shortcut to the ServiceManager Mock
-        self.services_mock = self.app.client_manager.identity.services
-        self.services_mock.reset_mock()
-
-
-class TestServiceCreate(TestService):
+class TestServiceCreate(identity_fakes.TestIdentityv3):
     columns = (
-        'description',
-        'enabled',
-        'id',
-        'name',
-        'type',
+        'ID',
+        'Name',
+        'Type',
+        'Enabled',
+        'Description',
     )
 
     def setUp(self):
-        super(TestServiceCreate, self).setUp()
+        super().setUp()
+
+        self.service = sdk_fakes.generate_fake_resource(_service.Service)
 
-        self.service = identity_fakes.FakeService.create_one_service()
         self.datalist = (
-            self.service.description,
-            True,
             self.service.id,
             self.service.name,
             self.service.type,
+            True,
+            self.service.description,
         )
-        self.services_mock.create.return_value = self.service
+        self.identity_sdk_client.create_service.return_value = self.service
 
         # Get the command object to test
         self.cmd = service.CreateService(self.app, None)
@@ -63,8 +57,7 @@ class TestServiceCreate(TestService):
         verifylist = [
             ('name', self.service.name),
             ('description', None),
-            ('enable', False),
-            ('disable', False),
+            ('is_enabled', True),
             ('type', self.service.type),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
@@ -74,12 +67,11 @@ class TestServiceCreate(TestService):
         # data to be shown.
         columns, data = self.cmd.take_action(parsed_args)
 
-        # ServiceManager.create(name=, type=, enabled=, **kwargs)
-        self.services_mock.create.assert_called_with(
+        self.identity_sdk_client.create_service.assert_called_with(
             name=self.service.name,
             type=self.service.type,
             description=None,
-            enabled=True,
+            is_enabled=True,
         )
 
         self.assertEqual(self.columns, columns)
@@ -94,8 +86,7 @@ class TestServiceCreate(TestService):
         verifylist = [
             ('name', None),
             ('description', self.service.description),
-            ('enable', False),
-            ('disable', False),
+            ('is_enabled', True),
             ('type', self.service.type),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
@@ -105,12 +96,11 @@ class TestServiceCreate(TestService):
         # data to be shown.
         columns, data = self.cmd.take_action(parsed_args)
 
-        # ServiceManager.create(name=, type=, enabled=, **kwargs)
-        self.services_mock.create.assert_called_with(
+        self.identity_sdk_client.create_service.assert_called_with(
             name=None,
             type=self.service.type,
             description=self.service.description,
-            enabled=True,
+            is_enabled=True,
         )
 
         self.assertEqual(self.columns, columns)
@@ -124,8 +114,7 @@ class TestServiceCreate(TestService):
         verifylist = [
             ('name', None),
             ('description', None),
-            ('enable', True),
-            ('disable', False),
+            ('is_enabled', True),
             ('type', self.service.type),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
@@ -135,12 +124,11 @@ class TestServiceCreate(TestService):
         # data to be shown.
         columns, data = self.cmd.take_action(parsed_args)
 
-        # ServiceManager.create(name=, type=, enabled=, **kwargs)
-        self.services_mock.create.assert_called_with(
+        self.identity_sdk_client.create_service.assert_called_with(
             name=None,
             type=self.service.type,
             description=None,
-            enabled=True,
+            is_enabled=True,
         )
 
         self.assertEqual(self.columns, columns)
@@ -154,8 +142,7 @@ class TestServiceCreate(TestService):
         verifylist = [
             ('name', None),
             ('description', None),
-            ('enable', False),
-            ('disable', True),
+            ('is_enabled', False),
             ('type', self.service.type),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
@@ -165,27 +152,28 @@ class TestServiceCreate(TestService):
         # data to be shown.
         columns, data = self.cmd.take_action(parsed_args)
 
-        # ServiceManager.create(name=, type=, enabled=, **kwargs)
-        self.services_mock.create.assert_called_with(
+        self.identity_sdk_client.create_service.assert_called_with(
             name=None,
             type=self.service.type,
             description=None,
-            enabled=False,
+            is_enabled=False,
         )
 
         self.assertEqual(self.columns, columns)
         self.assertEqual(self.datalist, data)
 
 
-class TestServiceDelete(TestService):
-    service = identity_fakes.FakeService.create_one_service()
+class TestServiceDelete(identity_fakes.TestIdentityv3):
+    service = sdk_fakes.generate_fake_resource(_service.Service)
 
     def setUp(self):
-        super(TestServiceDelete, self).setUp()
+        super().setUp()
 
-        self.services_mock.get.side_effect = identity_exc.NotFound(None)
-        self.services_mock.find.return_value = self.service
-        self.services_mock.delete.return_value = None
+        self.identity_sdk_client.get_service.side_effect = (
+            sdk_exceptions.ResourceNotFound
+        )
+        self.identity_sdk_client.find_service.return_value = self.service
+        self.identity_sdk_client.delete_service.return_value = None
 
         # Get the command object to test
         self.cmd = service.DeleteService(self.app, None)
@@ -201,19 +189,19 @@ class TestServiceDelete(TestService):
 
         result = self.cmd.take_action(parsed_args)
 
-        self.services_mock.delete.assert_called_with(
+        self.identity_sdk_client.delete_service.assert_called_with(
             self.service.id,
         )
         self.assertIsNone(result)
 
 
-class TestServiceList(TestService):
-    service = identity_fakes.FakeService.create_one_service()
+class TestServiceList(identity_fakes.TestIdentityv3):
+    service = sdk_fakes.generate_fake_resource(_service.Service)
 
     def setUp(self):
-        super(TestServiceList, self).setUp()
+        super().setUp()
 
-        self.services_mock.list.return_value = [self.service]
+        self.identity_sdk_client.services.return_value = [self.service]
 
         # Get the command object to test
         self.cmd = service.ListService(self.app, None)
@@ -228,7 +216,7 @@ class TestServiceList(TestService):
         # containing the data to be listed.
         columns, data = self.cmd.take_action(parsed_args)
 
-        self.services_mock.list.assert_called_with()
+        self.identity_sdk_client.services.assert_called_with()
 
         collist = ('ID', 'Name', 'Type')
         self.assertEqual(collist, columns)
@@ -255,7 +243,7 @@ class TestServiceList(TestService):
         # containing the data to be listed.
         columns, data = self.cmd.take_action(parsed_args)
 
-        self.services_mock.list.assert_called_with()
+        self.identity_sdk_client.services.assert_called_with()
 
         collist = ('ID', 'Name', 'Type', 'Description', 'Enabled')
         self.assertEqual(collist, columns)
@@ -271,15 +259,17 @@ class TestServiceList(TestService):
         self.assertEqual(datalist, tuple(data))
 
 
-class TestServiceSet(TestService):
-    service = identity_fakes.FakeService.create_one_service()
+class TestServiceSet(identity_fakes.TestIdentityv3):
+    service = sdk_fakes.generate_fake_resource(_service.Service)
 
     def setUp(self):
-        super(TestServiceSet, self).setUp()
+        super().setUp()
 
-        self.services_mock.get.side_effect = identity_exc.NotFound(None)
-        self.services_mock.find.return_value = self.service
-        self.services_mock.update.return_value = self.service
+        self.identity_sdk_client.get_service.side_effect = (
+            sdk_exceptions.ResourceNotFound
+        )
+        self.identity_sdk_client.find_service.return_value = self.service
+        self.identity_sdk_client.update_service.return_value = self.service
 
         # Get the command object to test
         self.cmd = service.SetService(self.app, None)
@@ -292,8 +282,7 @@ class TestServiceSet(TestService):
             ('type', None),
             ('name', None),
             ('description', None),
-            ('enable', False),
-            ('disable', False),
+            ('is_enabled', None),
             ('service', self.service.name),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
@@ -312,8 +301,7 @@ class TestServiceSet(TestService):
             ('type', self.service.type),
             ('name', None),
             ('description', None),
-            ('enable', False),
-            ('disable', False),
+            ('is_enabled', None),
             ('service', self.service.name),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
@@ -323,9 +311,11 @@ class TestServiceSet(TestService):
         # Set expected values
         kwargs = {
             'type': self.service.type,
+            'is_enabled': None,
         }
-        # ServiceManager.update(service, name=, type=, enabled=, **kwargs)
-        self.services_mock.update.assert_called_with(self.service.id, **kwargs)
+        self.identity_sdk_client.update_service.assert_called_with(
+            self.service.id, **kwargs
+        )
         self.assertIsNone(result)
 
     def test_service_set_name(self):
@@ -338,8 +328,7 @@ class TestServiceSet(TestService):
             ('type', None),
             ('name', self.service.name),
             ('description', None),
-            ('enable', False),
-            ('disable', False),
+            ('is_enabled', None),
             ('service', self.service.name),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
@@ -349,9 +338,11 @@ class TestServiceSet(TestService):
         # Set expected values
         kwargs = {
             'name': self.service.name,
+            'is_enabled': None,
         }
-        # ServiceManager.update(service, name=, type=, enabled=, **kwargs)
-        self.services_mock.update.assert_called_with(self.service.id, **kwargs)
+        self.identity_sdk_client.update_service.assert_called_with(
+            self.service.id, **kwargs
+        )
         self.assertIsNone(result)
 
     def test_service_set_description(self):
@@ -364,8 +355,7 @@ class TestServiceSet(TestService):
             ('type', None),
             ('name', None),
             ('description', self.service.description),
-            ('enable', False),
-            ('disable', False),
+            ('is_enabled', None),
             ('service', self.service.name),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
@@ -375,9 +365,11 @@ class TestServiceSet(TestService):
         # Set expected values
         kwargs = {
             'description': self.service.description,
+            'is_enabled': None,
         }
-        # ServiceManager.update(service, name=, type=, enabled=, **kwargs)
-        self.services_mock.update.assert_called_with(self.service.id, **kwargs)
+        self.identity_sdk_client.update_service.assert_called_with(
+            self.service.id, **kwargs
+        )
         self.assertIsNone(result)
 
     def test_service_set_enable(self):
@@ -389,8 +381,7 @@ class TestServiceSet(TestService):
             ('type', None),
             ('name', None),
             ('description', None),
-            ('enable', True),
-            ('disable', False),
+            ('is_enabled', True),
             ('service', self.service.name),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
@@ -399,10 +390,11 @@ class TestServiceSet(TestService):
 
         # Set expected values
         kwargs = {
-            'enabled': True,
+            'is_enabled': True,
         }
-        # ServiceManager.update(service, name=, type=, enabled=, **kwargs)
-        self.services_mock.update.assert_called_with(self.service.id, **kwargs)
+        self.identity_sdk_client.update_service.assert_called_with(
+            self.service.id, **kwargs
+        )
         self.assertIsNone(result)
 
     def test_service_set_disable(self):
@@ -414,8 +406,7 @@ class TestServiceSet(TestService):
             ('type', None),
             ('name', None),
             ('description', None),
-            ('enable', False),
-            ('disable', True),
+            ('is_enabled', False),
             ('service', self.service.name),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
@@ -424,21 +415,24 @@ class TestServiceSet(TestService):
 
         # Set expected values
         kwargs = {
-            'enabled': False,
+            'is_enabled': False,
         }
-        # ServiceManager.update(service, name=, type=, enabled=, **kwargs)
-        self.services_mock.update.assert_called_with(self.service.id, **kwargs)
+        self.identity_sdk_client.update_service.assert_called_with(
+            self.service.id, **kwargs
+        )
         self.assertIsNone(result)
 
 
-class TestServiceShow(TestService):
-    service = identity_fakes.FakeService.create_one_service()
+class TestServiceShow(identity_fakes.TestIdentityv3):
+    service = sdk_fakes.generate_fake_resource(_service.Service)
 
     def setUp(self):
-        super(TestServiceShow, self).setUp()
+        super().setUp()
 
-        self.services_mock.get.side_effect = identity_exc.NotFound(None)
-        self.services_mock.find.return_value = self.service
+        self.identity_sdk_client.get_service.side_effect = (
+            sdk_exceptions.ResourceNotFound
+        )
+        self.identity_sdk_client.find_service.return_value = self.service
 
         # Get the command object to test
         self.cmd = service.ShowService(self.app, None)
@@ -457,22 +451,25 @@ class TestServiceShow(TestService):
         # data to be shown.
         columns, data = self.cmd.take_action(parsed_args)
 
-        # ServiceManager.get(id)
-        self.services_mock.find.assert_called_with(name=self.service.name)
+        self.identity_sdk_client.find_service.assert_called_with(
+            self.service.name, ignore_missing=False
+        )
 
-        collist = ('description', 'enabled', 'id', 'name', 'type')
+        collist = ('ID', 'Name', 'Type', 'Enabled', 'Description')
         self.assertEqual(collist, columns)
         datalist = (
-            self.service.description,
-            True,
             self.service.id,
             self.service.name,
             self.service.type,
+            True,
+            self.service.description,
         )
         self.assertEqual(datalist, data)
 
     def test_service_show_nounique(self):
-        self.services_mock.find.side_effect = identity_exc.NoUniqueMatch(None)
+        self.identity_sdk_client.find_service.side_effect = (
+            sdk_exceptions.DuplicateResource(None)
+        )
         arglist = [
             'nounique_service',
         ]
@@ -486,7 +483,6 @@ class TestServiceShow(TestService):
             self.fail('CommandError should be raised.')
         except exceptions.CommandError as e:
             self.assertEqual(
-                "Multiple service matches found for 'nounique_service',"
-                " use an ID to be more specific.",
+                "DuplicateResource",
                 str(e),
             )
